==> haskell-cryptohash-sha1-0.11.100.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha1
version: 0.11.100.1
id: cryptohash-sha1-0.11.100.1-CglqrWLTxPN69LKXoyo6
key: cryptohash-sha1-0.11.100.1-CglqrWLTxPN69LKXoyo6
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha1
synopsis: Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
exposed-modules:
    Crypto.Hash.SHA1
abi: 3a3bc0ba224e2edb53f1c56c1d580c65
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-sha1-0.11.100.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-sha1-0.11.100.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/cryptohash-sha1-0.11.100.1
hs-libraries: HScryptohash-sha1-0.11.100.1-CglqrWLTxPN69LKXoyo6
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-sha1-0.11.100.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha1
version: 0.11.100.1
id: cryptohash-sha1-0.11.100.1-AJqtLjVn8sfKvw8ebixA3z
key: cryptohash-sha1-0.11.100.1-AJqtLjVn8sfKvw8ebixA3z
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha1
synopsis: Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
exposed-modules:
    Crypto.Hash.SHA1
abi: 5a33b5f7813481b9ec9545caa6e7bd7a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-sha1-0.11.100.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-sha1-0.11.100.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/cryptohash-sha1-0.11.100.1
hs-libraries: HScryptohash-sha1-0.11.100.1-AJqtLjVn8sfKvw8ebixA3z
depends:
    base-4.9.1.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
